slepc-3.18.0 2022-10-01
Report Typos and Errors

# BVSetMatMultMethod

Specifies the method used for the BVMatMult() operation.

### Synopsis

    #include "slepcbv.h"
    PetscErrorCode BVSetMatMultMethod(BV bv,BVMatMultType method)

Logically Collective on bv

### Input Parameters

| bv | - the basis vectors context
| method | - the method for the BVMatMult() operation

### Options Database Keys

| -bv_matmult <meth> | - choose one of the methods: vecs, mat

### Notes

Allowed values are

| BV_MATMULT_VECS | - perform a matrix-vector multiply per each column
| BV_MATMULT_MAT | - carry out a Mat-Mat product with a dense matrix
| BV_MATMULT_MAT_SAVE | - this case is deprecated

The default is BV_MATMULT_MAT except in the case of BVVECS.

### See Also

BVMatMult(), BVGetMatMultMethod(), BVMatMultType

### Level

advanced

### Location

src/sys/classes/bv/interface/bvbasic.c
Index of all BV routines
Table of Contents for all manual pages
Index of all manual pages